import request from "@/utils/request";

//获取当前列表
export function dataArrayList(processId: string,deviceNo :string,pageNo :string) {
  return request({
    url: `/api/v1/testData/get/${processId}/${deviceNo}/${pageNo}`,
    method: "get",
  });
}

export function startCSSJTesting(data: any) {
  return request({
    url: `/api/v1/testData/startTest`,
    method: "post",
    data: data,
  });
}

export function deleteCSSJ(id: string) {
  return request({
    url: `/api/v1/testData/del`,
    method: "post",
    data: {
      id: id,
    },
  });
}

export function addCSSJ(data: any) {
  return request({
    url: `/api/v1/testData/save`,
    method: "post",
    data: data,
  });
}

export function getDeviceList(data: any) {
  return request({
    url: `/api/v1/device/list`,
    method: "post",
    data: data,
  });
}

export function getDeviceListPage(data: any) {
  return request({
    url: `/api/v1/device/page`,
    method: "post",
    data: data,
  });
}


export function getDataDevice(data: any) {
    return request({
        url: `api/v1/processDataDevice/list`,
        method: "post",
        data: data,
    });
}

export function addDataDevice(data: any) {
    return request({
        url: `api/v1/processDataDevice/add`,
        method: "post",
        data: data,
    });
}

export function delDataDevice(data: any) {
    return request({
        url: `api/v1/processDataDevice/del`,
        method: "post",
        data: data,
    });
}
